#  tests for kealib-1.4.7-h9feed0d_5 (this is a generated file);
print('===== testing package: kealib-1.4.7-h9feed0d_5 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---

# just load kealib using ctypes
import os
import sys
import ctypes

if sys.platform == 'win32':
    kealib = ctypes.CDLL('libkea.dll')
elif sys.platform == 'darwin':
    # LD_LIBRARY_PATH not set on OSX
    keapath = os.path.expandvars('$PREFIX/lib/libkea.dylib')
    kealib = ctypes.CDLL(keapath)
else:
    kealib = ctypes.CDLL('libkea.so')

#  --- run_test.py (end) ---

print('===== kealib-1.4.7-h9feed0d_5 OK =====');
